function [ G, grad_g ] = gfun_ex8(lsf,x,grad_flag,probdata,analysisopt,gfundata,femodel,randomfield)

global nfun

% rand('state',sum(100*clock))

LINEAR = 0;  % non linear model
%LINEAR = 1; % linear model

ndof = 5;      % number of degrees of freedom
nsteps = 2001; % number of integration steps
dt = 0.01;     % time interval

M   = x(1:5,1);
Kd  = x(6:10,1);
R   = x(11:15,1);
S_K = x(16:20,1);
Z   = x(21:25,1);

% M   = [  20e3,   20e3,   20e3,   20e3,   20e3]'; % mass (Kg)
% Kd  = [  24e6,   21e6,   18e6,   15e6,   12e6]'; % stiffness (N/m)
% R   = [ 2.4e6,  2.1e6,  1.8e6,  1.5e6,  1.2e6]'; % stiffness (N/m)
% S_K = [ 0.008,  0.008,  0.008,  0.008,  0.008]'; % s/k
% Z   = [  0.06,   0.06,   0.06,   0.06,   0.06]'; % damping (-)

S = S_K.*Kd;
C =  (2*Z.*sqrt(M.*(Kd+R)))';  % damping constant	

% Simulation of base acceleration 
t = 0:dt:(dt*(nsteps-1));
a = Hz_accel(t,x(26:225,1));

% Initial conditions
u0  = zeros(ndof,1);
ud0 = zeros(ndof,1);


if ~LINEAR
   param = cell(1,ndof);
   for w=1:ndof
      param{w} = restoringforce(Kd(w),R(w),S(w)); %Initialize hysteresis loop
   end
end   

p = -M*a;

M = diag(M);     
C = ckmatrix3(C); % assemble C matrix

if (~LINEAR)
   kTdiag = zeros(1,ndof);
else
   kT = ckmatrix3((Kd+R)');
end   

gamma = 0.5; beta = 0.25; % average acceleration method

bdt = beta*dt;
g_b = gamma/beta;
g_2b = g_b/2;
g_bdt = g_b/dt;
dt2 = dt*dt;
bdt2 = beta*dt2;
one_bdt2 = 1/bdt2;
one_2b = 1/(2*beta);

u   = zeros(ndof,nsteps);    % absolute displacement
ud  = zeros(ndof,nsteps);    % velocity
udd = zeros(ndof,nsteps);    % acceleration
fs  = zeros(ndof,nsteps);    % restoring force
resfor = zeros(ndof,nsteps); 
ru  = zeros(ndof,nsteps);    % relative displacement

u(:,1)  = u0;
ud(:,1) = ud0;

if ~LINEAR
   
   for w = 1:ndof
      [ resfor(w,1), kTdiag(w), param{w} ] = restoringforce(u0(w),0,ud0(w),0,0,param{w});
   end
	fs(:,1) = [ -diff(resfor(:,1)); resfor(ndof,1) ];
   kT = ckmatrix3(kTdiag);
   
else
   
   fs(:,1) = kT*u0;
   
end

udd(:,1) = M\(p(:,1) - C*ud0 - fs(:,1));
A = (1/bdt)*M + g_b*C;
B = (1/(2*beta))*M + dt*(g_2b-1)*C;

kgT = kT + g_bdt*C + one_bdt2*M;

period = zeros(ndof,nsteps);
period(:,1) = (2*pi)./sqrt(eig(full(kT),full(M)));

fsj = zeros(ndof,1);

for i = 1:(nsteps-1)
   
%   if ~mod(i,1000), fprintf('i = %d/%d\n',i,nsteps-1); end
   
   ui   = u(:,i);
   udi  = ud(:,i);
   uddi = udd(:,i);
   dpi  = p(:,i+1) - p(:,i);
   dpgi = dpi + A*udi + B*uddi;
	
   %Solve for duj from kgi and dpgi using Newton-Raphson
   %BEGIN NEWTON RAPHSON
   
   resfor0 = resfor(:,i);
	fs0 = fs(:,i);
   dR = dpgi;
   j = 0;
   duj = zeros(ndof,1);
   
   ru0 = [ ui(1);  diff(ui) ];
   rv0 = [ udi(1); diff(udi) ];   
   
   while 1
      
      j = j + 1;
      
      if j > 10000
         error('Newton Raphson is not converging');
      end
      
      dujold = duj;
      duj  = kgT\dR;
      dudj = g_bdt*duj - g_b*udi + dt*(1-g_2b)*uddi;
      uj = ui  + duj;
      vj = udi + dudj;

      if ~LINEAR
         
         ruj = [ uj(1); diff(uj) ];
         rvj = [ vj(1); diff(vj) ];
          
         for w=1:ndof
            [ resfor(w,i+1), kTdiag(w), param{w} ] = restoringforce(ruj(w),ru0(w),rvj(w),rv0(w),resfor0(w),param{w});
         end
			fsj = [-diff(resfor(:,i+1)); resfor(ndof,i+1)];
			
         kT = ckmatrix3(kTdiag);      
         kgT = kT + g_bdt*C + one_bdt2*M;
         
      else
         
         fsj = kT*uj;
         
      end
      
      df = (fsj - fs0) - kT*duj;
      dR = dpgi - df;
      
      if ( norm(duj-dujold) < 1e-12 ) | ( norm(df) < 1e-12 ), break, end
      
   end
		
   fs(:,i+1) = fsj;
   
   if ~LINEAR
      ru(:,i+1) = ruj;
   end
   
   %END NEWTON RAPHSON

   duddi = (1/bdt2)*duj - (1/bdt)*udi - one_2b*uddi;
   u(:,i+1)   = uj;
   ud(:,i+1)  = vj;
   udd(:,i+1) = uddi + duddi;
   
end

% figure; plot(t,a);   	xlabel('Time (s)'); ylabel('Excitation force (N)'); grid
% 
% figure; plot(t,u);   	xlabel('Time (s)'); ylabel('Displacement (m)');
% legend('dof 1','dof 2','dof 3','dof 4','dof 5',0); grid
% 
% figure; plot(t,ud);  	xlabel('Time (s)'); ylabel('Velocity (m/s)');
% legend('dof 1','dof 2','dof 3','dof 4','dof 5',0); grid
% 
% figure; plot(t,udd); 	xlabel('Time (s)'); ylabel('Acceleration (m/s^2)');
% legend('dof 1','dof 2','dof 3','dof 4','dof 5',0); grid
% 
% figure; plot(t,ru); 	xlabel('Time (s)'); ylabel('Relative displacement(m/s^2)');
% legend('dof 1-2','dof 2-3','dof 3-4','dof 4-5',0); grid

% if ~LINEAR
%    for w = 1:ndof
%       figure; plot(ru(w,:),resfor(w,:));
% 		xlabel('Relative displacement (m)'); ylabel('Restoring force (N)');
% 		title(['Hysteresis DOF = ' num2str(w)]);      
% 		grid
%    end
% end

switch gfundata(lsf).cg(2)
   case inf
      G = max(ru(gfundata(lsf).cg(1),:));
   case -inf
      G = min(ru(gfundata(lsf).cg(1),:));
   case 0
      G = max(abs(ru(gfundata(lsf).cg(1),:)));
   otherwise
      G = gfundata(lsf).cg(2) - max(abs(ru(gfundata(lsf).cg(1),:)));
end
grad_g = 0;

% Update number of calls to the limit state function
nfun = nfun + 1;
